Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2787)

Unified Diff: content/renderer/render_frame_impl.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/render_frame_impl.cc
diff --git a/content/renderer/render_frame_impl.cc b/content/renderer/render_frame_impl.cc
index 971139b74cf092f919dfb1fd60dcab7bf2a1c30f..123f3f68b5b8e6b1e82cb10e0aacbf560c1153ee 100644
--- a/content/renderer/render_frame_impl.cc
+++ b/content/renderer/render_frame_impl.cc
@@ -5086,10 +5086,10 @@ void RenderFrameImpl::SendDidCommitProvisionalLoad(
render_view_->SetZoomLevel(render_view_->page_zoom_level());
}
// Standard URLs must match the reported origin, when it is not unique.
// This check is very similar to RenderFrameHostImpl::CanCommitOrigin, but
// adapted to the renderer process side.
- if (!params.origin.unique() && params.url.IsStandard() &&
+ if (!params.origin.opaque() && params.url.IsStandard() &&
render_view_->GetWebkitPreferences().web_security_enabled) {
// Exclude file: URLs when settings allow them access any origin.
if (params.origin.scheme() != url::kFileScheme ||
@@ -5086,10 +5086,10 @@ void RenderFrameImpl::SendDidCommitProvisionalLoad(
render_view_->SetZoomLevel(render_view_->page_zoom_level());
}
- // Standard URLs must match the reported origin, when it is not unique.
+ // Standard URLs must match the reported origin, when it is not opaque.
// This check is very similar to RenderFrameHostImpl::CanCommitOrigin, but
// adapted to the renderer process side.

Powered by Google App Engine
This is Rietveld 408576698